import clsx from "clsx";
import { CSSProperties, FC, PropsWithChildren } from "react";
import { twMerge } from "tailwind-merge";
interface Props {
    pt?: boolean;
    pb?: boolean;
    pl?: boolean;
    pr?: boolean;
    none?: boolean;
    className?: string;
    style?: CSSProperties;
}

/**
 * @description
 * 1`:接受padding属性， 有默认值， 有自定义值, 默认显示， 可自定并且合并
 * todo 2: 可通过 clo / row 定义flex 布局
 * todo 3: 可设置背景
 */
const Box: FC<PropsWithChildren<Props>> = (props) => {
    const {
        className,
        children,
        pt = true,
        pb = true,
        pl = true,
        pr = true,
        none = false,
        style,
    } = props;

    const cls = clsx(
        !none && {
            ["pt-[0.08rem]"]: pt,
            ["pb-[0.08rem]"]: pb,
            ["px-[0.12rem]"]: pl || pr,
        },
        className
    );
    return (
        <div className={twMerge(cls)} style={style}>
            {children}
        </div>
    );
};

export default Box;
